@@ -48,7 +48,7 @@ BranchHistory::BranchHistory(uint objid_)
 	vectortable = GetVectorTable();
 
 	monitor = gMonitorManager->Regist(monitor_id, this);
-	monitor->func = ToMonitorCallback(&BranchHistory::MonitorUpdate);
+	monitor->SetCallback(&BranchHistory::MonitorScreen);
 	monitor->SetSize(55, 1 + 32); // ヘッダ1行とエントリ数
 	monitor->SetMaxHeight(1 + 256);
 
@@ -92,7 +92,7 @@ BranchHistory::GetUsed() const
 
 // モニタ更新
 void
-BranchHistory::MonitorUpdate(Monitor *, TextScreen& screen)
+BranchHistory::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	uint8 t;
 	int y;
