@@ -37,7 +37,6 @@
 #include "debugger_m680x0.h"
 #include "debugger_m88xx0.h"
 #include "ascii_ctype.h"
-#include "event.h"
 #include "hostcom.h"
 #include "mainapp.h"
 #include "memdump.h"
@@ -66,7 +65,7 @@ Debugger::Debugger()
 
 	// ブレークポイントモニタ
 	bpoint_monitor = gMonitorManager->Regist(ID_MONITOR_BREAKPOINT, this);
-	bpoint_monitor->func = ToMonitorCallback(&Debugger::MonitorUpdateBpoint);
+	bpoint_monitor->SetCallback(&Debugger::MonitorScreenBpoint);
 	bpoint_monitor->SetSize(59, 9);
 
 	// メモリダンプモニタ
@@ -2052,7 +2051,7 @@ Debugger::cmd_b_list()
 
 // ブレークポイント一覧 (モニタ)
 void
-Debugger::MonitorUpdateBpoint(Monitor *, TextScreen& monitor)
+Debugger::MonitorScreenBpoint(Monitor *, TextScreen& monitor)
 {
 	// 0         1         2         3         4         5         6
 	// 0123456789012345678901234567890123456789012345678901234567890
@@ -2291,7 +2290,7 @@ Debugger::cmd_hist_common(BranchHistory& hist)
 	// 表示行数 + 1行はヘッダ分
 	int lines = std::min(used, maxlines) + 1;
 
-	// MonitorUpdate() は TextScreen 高さに合わせて出力してくれる。
+	// MonitorScreen() は TextScreen 高さに合わせて出力してくれる。
 	auto *histmon = hist.monitor;
 	TextScreen screen;
 	screen.Init(histmon->GetCol(), lines);
@@ -2302,7 +2301,7 @@ Debugger::cmd_hist_common(BranchHistory& hist)
 	}
 
 	// 表示
-	histmon->Update(screen);
+	histmon->UpdateScreen(screen);
 	ShowTextScreen(screen);
 
 	return CmdAct::Stay;
@@ -2949,7 +2948,8 @@ Debugger::ShowMonitor(Monitor *monitor)
 	auto size = monitor->GetSize();
 	ts.Init(size.width, size.height);
 
-	monitor->Update(ts);
+	// テキストだけで表示
+	monitor->UpdateScreen(ts);
 	ShowTextScreen(ts);
 }
 
