@@ -264,7 +264,7 @@ class Debugger : public ThreadDevice
 	std::string bpointmsg {};
 
 	// ブレークポイントモニタ
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateBpoint);
+	DECLARE_MONITOR_SCREEN(MonitorScreenBpoint);
 	Monitor *bpoint_monitor {};
 
 	// 逆アセンブルとメモリダンプモニタ
