@@ -727,3 +727,13 @@ DebuggerMD_m680x0::Disassemble(DebuggerMemoryStream& mem)
 
 	return str;
 }
+
+// 命令ニーモニックに対するバイナリを文字列形式で返す。
+// 対応しない場合は "" を返す。cmd_bi 用。
+std::string
+DebuggerMD_m680x0::ParseInst(const std::string& inst) const
+{
+	if (inst == "rte")		return "4e73";
+
+	return "";
+}
