@@ -18,6 +18,18 @@
 <div class="main1">
 <dl>
 
+<dt>1.6.2 (2025/11/11)
+<dd><ul>
+<li>m68k(Fix): 68881 の FRESTORE 命令がヌルステートフレームの長さフィールドを無視するよう修正。
+ <q>Fix the FRESTORE instruction to ignore the length field in null-state frame on 68881.</q>
+</ul><p>
+
+<dt>1.6.1 (2025/11/07)
+<dd><ul>
+<li>m88k(Update): 疑似 STOP 状態を OpenBSD/luna88k 7.8 にも対応。
+ <q>Pseudo STOP state now supports OpenBSD/luna88k 7.8.</q>
+</ul><p>
+
 <dt>1.6.0 (2025/10/29)
 <dd><ul>
 <li>host(New): サウンド出力を実装。<q>Implement sound output.</q>
@@ -31,10 +43,6 @@
  <q>Separate loglevel per channel.</q>
 <li>vm(Update): Human68k モードの FPACK __LTOS を実装。
  <q>Implement FPACK __LTOS on Human68k mode.</q>
-<li>GUI(New): スレッドモニタを実装。
- <q>Implement thread monitor.</q>
-<li>app(New): ヘテロジニアス構成 CPU のコアの指定に (正式に) 対応。
- <q>Support specifying cores for heterogeneous CPU (formally).</q>
 <li>vm(Fix): X68030 もキー押下で高速モードを抑制するように戻す。
 ver 1.5.0 で廃止したが副作用があったため。
  <q>Revert to suppressing full speed mode on key press on X68030.
@@ -44,6 +52,10 @@ ver 1.5.0 で廃止したが副作用があったため。
  <tt>hostcpu-avx2</tt>, <tt>hostcpu-neon</tt> にリネーム。
  <q><tt>host-avx2</tt>, <tt>host-neon</tt> are renamed to
  <tt>hostcpu-avx2</tt>, <tt>hostcpu-neon</tt>.</q>
+<li>GUI(New): スレッドモニタを実装。
+ <q>Implement thread monitor.</q>
+<li>app(New): ヘテロジニアス構成 CPU のコアの指定に (正式に) 対応。
+ <q>Support specifying cores for heterogeneous CPU (formally).</q>
 <li>app(Fix): NetBSD 11.0_BETA で設定ファイルに非 ASCII
  文字があると不正終了する場合があったのを修正。
  <q>Fix possible abnormal termination if the configuration file contains
@@ -86,9 +98,10 @@ NetBSD/x68k の X サーバが標準設定で動きます。
 <li>m88k(Update): テーブルサーチは暗黙で CI 扱いになるところを実装。
  <q>Implement a table search operation with CI.</q>
 <li>m88k(Update): CI アクセスでキャッシュヒットするとエントリが無効化されるところを実装。
-この2点で、ver 0.7.1 以降 OpenBSD がまれに panic していたのが直ると思います。
+この2点で、ver 0.7.1 以降 OpenBSD/luna88k がまれに panic
+していたのが直ると思います。
  <q>Implement that a cache hit invalidates the cache entry if the accesss is CI.
- These two changes should fix an occasional OpenBSD panic since ver 0.7.1.</q>
+ These two changes should fix an occasional OpenBSD/luna88k panic since ver 0.7.1.</q>
 <li>m88k(Fix): CI 領域に対する xmem 命令の動作を修正。
  <q>Fix the behavior of the xmem instruction in a cache-inhibited region.</q>
 <li>m88k(Fix): バススヌープでキャッシュの状態が変わらない場合があったのを修正。
