@@ -30,7 +30,7 @@ HD647180ASCIDevice::HD647180ASCIDevice()
 	}
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_XPASCI, this);
-	monitor->func = ToMonitorCallback(&HD647180ASCIDevice::MonitorUpdate);
+	monitor->SetCallback(&HD647180ASCIDevice::MonitorScreen);
 	monitor->SetSize(63, 12);
 }
 
@@ -517,16 +517,16 @@ HD647180ASCIDevice::PeekRDR(uint n) const
 }
 
 void
-HD647180ASCIDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+HD647180ASCIDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
-	MonitorUpdateChan(screen, 0, 0);
-	MonitorUpdateChan(screen, 6, 1);
+	MonitorScreenChan(screen, 0, 0);
+	MonitorScreenChan(screen, 6, 1);
 }
 
 void
-HD647180ASCIDevice::MonitorUpdateChan(TextScreen& screen, int y, int n) const
+HD647180ASCIDevice::MonitorScreenChan(TextScreen& screen, int y, int n) const
 {
 	Channel tmp = channels[n];
 	uint32 cntla = PeekCNTLA(n);
