@@ -57,18 +57,6 @@ HostDevice::Create2()
 	return true;
 }
 
-// 初期化
-bool
-HostDevice::Init()
-{
-	// Create2() と Config::Fix が終わったところで fallback をオンにする。
-	// これ以降の動的変更でエラー終了するのは困るので。
-	std::string line = GetConfigKey() + "-fallback=1";
-	gConfig->UpdateRunning(line);
-
-	return true;
-}
-
 // 設定ファイルキーのプレフィックス ("hostcomX" とか) を返す
 std::string
 HostDevice::GetConfigKey() const
