@@ -56,7 +56,7 @@ class HostSoundDevice : public HostDevice
 	// 外部からの読み込み (未対応)
 	int Read() override;
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	std::unique_ptr<SoundDriver> driver {};
 
