@@ -10,6 +10,7 @@
 
 #include "hostwindrv.h"
 #include "ascii_ctype.h"
+#include "mytime.h"
 #include <dirent.h>
 #include <inttypes.h>
 #include <fcntl.h>
@@ -834,9 +835,11 @@ HostWindrv::SetFileTime(Windrv::FCB *fcb, uint32 datetime)
 
 	// [0] が atime、[1] が mtime。
 	struct timeval times[2];
-	times[1].tv_sec = Human68k::DateTime2Unixtime(datetime);
+	uint64 now = get_hosttime_usec();
+	times[0].tv_sec  = now / 1000'000U;
+	times[0].tv_usec = now % 1000'000U;
+	times[1].tv_sec  = Human68k::DateTime2Unixtime(datetime);
 	times[1].tv_usec = 0;
-	gettimeofday(&times[0], NULL);
 	int r = futimes(fcb->fd, times);
 	if (r < 0) {
 		putmsg(1, "%s: futimes: %s", __func__, strerror(errno));
