@@ -67,7 +67,7 @@ class Logger : public Object, public ThreadBase
 	void AddLog(const std::string&);
 	void AddDisplay(const std::string&);
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// ログ受け付けキュー。
 	std::deque<std::string> queue {};
