@@ -169,7 +169,7 @@ NetDriverAFPacket::Close()
 
 // モニタ (ドライバ依存情報のみ)
 void
-NetDriverAFPacket::MonitorUpdateMD(TextScreen& screen, int y)
+NetDriverAFPacket::MonitorScreenMD(TextScreen& screen, int y)
 {
 	screen.Print(0, y, "Interface: %s", ifname.c_str());
 }
