@@ -168,7 +168,7 @@ NetDriverBPF::Close()
 
 // モニタ (ドライバ依存情報のみ)
 void
-NetDriverBPF::MonitorUpdateMD(TextScreen& screen, int y)
+NetDriverBPF::MonitorScreenMD(TextScreen& screen, int y)
 {
 	screen.Print(0, y++, "Device   : %s", devpath.c_str());
 	screen.Print(0, y++, "Interface: %s", ifname.c_str());
