@@ -163,7 +163,7 @@ NetDriverSlirp::Close()
 
 // モニタ (ドライバ依存情報のみ)
 void
-NetDriverSlirp::MonitorUpdateMD(TextScreen& screen, int y)
+NetDriverSlirp::MonitorScreenMD(TextScreen& screen, int y)
 {
 	// なし
 }
@@ -447,7 +447,7 @@ SlirpThread::InitBackend(const std::string& key, int *rxdp, int *txdp)
 	monitor = gMonitorManager->Find(ID_MONITOR_SLIRP);
 	assert(monitor);
 	monitor->obj = this;
-	monitor->func = ToMonitorCallback(&SlirpThread::MonitorUpdate);
+	monitor->SetCallback(&SlirpThread::MonitorScreen);
 	monitor->SetSize(80, 40);
 
 	return true;
@@ -1139,7 +1139,7 @@ SlirpThread::UpdateInfo()
 }
 
 void
-SlirpThread::MonitorUpdate(Monitor *, TextScreen& screen)
+SlirpThread::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	std::string local_conn;
 	std::string local_nbr;
