@@ -34,7 +34,10 @@ class MappedFile final
 
 	// サイズの確定しているファイルを読み書き両用でオープンして mmap する。
 	// ファイルがなければ作成する。SRAM とか用。
-	uint8 *OpenCreate(off_t len);
+	uint8 *OpenCreate(off_t len) {
+		return OpenCreate(len, NULL, 0);
+	}
+	uint8 *OpenCreate(off_t len, const uint8 *data, uint datalen);
 
 	// クローズする (デストラクタを呼ぶだけでもよい)
 	void Close();
