@@ -43,7 +43,8 @@ static constexpr uint OBJ_XP_MEMDUMP(uint n) { return OBJ_XP_MEMDUMP0 + n; }
 // モニタコールバックを宣言するマクロ。
 // 強制力はないけどヘッダで宣言するところで使うこと。
 // コールバック関数の型が変わった時にコンパイルエラーで検出させるため。
-#define DECLARE_MONITOR_CALLBACK(name)	void name (Monitor *, TextScreen&)
+#define DECLARE_MONITOR_SCREEN(name)	void name (Monitor *, TextScreen&)
+#define DECLARE_MONITOR_BITMAP(name)	void name (Monitor *, BitmapRGBX&)
 
 // 基本オブジェクト
 class Object
