@@ -662,7 +662,7 @@ m68040ATC::Flush(busaddr addr, bool only_non_global)
 
 // モニター更新 (68040 ATC)
 void
-MPU68040Device::MonitorUpdateATC(Monitor *, TextScreen& screen)
+MPU68040Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 {
 	int x = 64;
 
@@ -677,12 +677,12 @@ MPU68040Device::MonitorUpdateATC(Monitor *, TextScreen& screen)
 	for (int i = 0; i < 4; i++) {
 		screen.Puts(i * 31 + (i & 2), 1, "IDX TagAddr     PAddr     Stat");
 	}
-	MonitorUpdateATC1(screen, 0, atc_data.get());
-	MonitorUpdateATC1(screen, x, atc_inst.get());
+	MonitorScreenATC1(screen, 0, atc_data.get());
+	MonitorScreenATC1(screen, x, atc_inst.get());
 }
 
 void
-MPU68040Device::MonitorUpdateATC1(TextScreen& screen, int x,
+MPU68040Device::MonitorScreenATC1(TextScreen& screen, int x,
 	const m68040ATC *atc)
 {
 	int y = 2;
