@@ -27,6 +27,7 @@
 
 #include "m88100.h"
 #include "debugger.h"
+#include "event.h"
 #include "mpu88xx0.h"
 #include "scheduler.h"
 
@@ -56,7 +57,7 @@ MPU88xx0Device::Prefetch()
 
 // 1命令実行のコールバック。
 void
-MPU88xx0Device::ExecNormal(Event& ev)
+MPU88xx0Device::ExecNormal(Event *ev)
 {
 	uint64 cycle_start = used_cycle;
 	uint32 op12;
@@ -99,7 +100,7 @@ MPU88xx0Device::ExecNormal(Event& ev)
 	Prefetch();
 
 	int cycle = used_cycle - cycle_start;
-	ev.time = cycle * clock_nsec + buswait;
+	ev->time = cycle * clock_nsec + buswait;
 	scheduler->StartEvent(ev);
 }
 
@@ -680,13 +681,6 @@ MPU88xx0Device::FPImpreciseException(uint32 cause)
 	OuterException(EXCPRI_SFU_IMPRECISE);
 }
 
-void
-MPU88xx0Device::fpu_unimpl()
-{
-	printf("%s\n", __func__);
-	FPPreciseException(FPECR_FUNIMP);
-}
-
 OP_DEF(illegal)
 {
 	// 不当命令例外。
