@@ -39,11 +39,11 @@ m88200::m88200(MPU88xx0Device *parent_, uint id_)
 	AddAlias(string_format("CMMU%u", id));
 
 	reg_monitor = gMonitorManager->Regist(ID_MONITOR_CMMU(id), this);
-	reg_monitor->func = ToMonitorCallback(&m88200::MonitorUpdateReg);
+	reg_monitor->SetCallback(&m88200::MonitorScreenReg);
 	reg_monitor->SetSize(52, 8);
 
 	atc_monitor = gMonitorManager->Regist(ID_MONITOR_ATC(id), this);
-	atc_monitor->func = ToMonitorCallback(&m88200::MonitorUpdateATC);
+	atc_monitor->SetCallback(&m88200::MonitorScreenATC);
 	uint h = 44;
 #if defined(M88200_STAT)
 	h += 16;
@@ -51,7 +51,7 @@ m88200::m88200(MPU88xx0Device *parent_, uint id_)
 	atc_monitor->SetSize(77, h);
 
 	cache_monitor = gMonitorManager->Regist(ID_SUBWIN_CACHE(id), this);
-	cache_monitor->func = ToMonitorCallback(&m88200::MonitorUpdateCache);
+	cache_monitor->SetCallback(&m88200::MonitorScreenCache);
 	cache_monitor->SetSize(82, 23);
 
 	// ログ表示用の名前
@@ -111,7 +111,7 @@ m88200::Reset()
 
 // モニター更新 (CMMU レジスタ)
 void
-m88200::MonitorUpdateReg(Monitor *, TextScreen& screen)
+m88200::MonitorScreenReg(Monitor *, TextScreen& screen)
 {
 	uint32 baseaddr;
 	uint32 reg;
@@ -184,7 +184,7 @@ m88200::MonitorUpdateReg(Monitor *, TextScreen& screen)
 
 // モニター更新 (ATC)
 void
-m88200::MonitorUpdateATC(Monitor *, TextScreen& screen)
+m88200::MonitorScreenATC(Monitor *, TextScreen& screen)
 {
 	int x;
 	int y;
@@ -378,7 +378,7 @@ m88200::MonitorUpdateATC(Monitor *, TextScreen& screen)
 // モニター更新 (キャッシュ、概要と詳細の両方、GUI から呼ばれる)
 // screen.userdata は注目しているセット番号。
 void
-m88200::MonitorUpdateCache(Monitor *, TextScreen& screen)
+m88200::MonitorScreenCache(Monitor *, TextScreen& screen)
 {
 	uint setidx = screen.userdata;
 
