@@ -164,9 +164,9 @@ class m88200 : public Device
 	void Reset();
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateReg);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateATC);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateCache);
+	DECLARE_MONITOR_SCREEN(MonitorScreenReg);
+	DECLARE_MONITOR_SCREEN(MonitorScreenATC);
+	DECLARE_MONITOR_SCREEN(MonitorScreenCache);
 
 	MPU88xx0Device *parent {};
 
