@@ -136,7 +136,7 @@ class BT454Device : public BT45xDevice
 	~BT454Device() override;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	uint32 ReadControl() override;
 	void WriteControl(uint32 data) override;
@@ -156,7 +156,7 @@ class BT458Device : public BT45xDevice
 	bool Init() override;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	uint32 ReadControl() override;
 	void WriteControl(uint32 data) override;
