@@ -93,7 +93,7 @@
 // time [nsec] 後に呼び出す phase_event のコールバックをセットする。
 // func の書式が面倒なのを省略して書きたいため。
 #define CallAfter(func_, time_)	do { \
-	phase_event->func = ToEventCallback(&FDCDevice::func_); \
+	phase_event->SetCallback(&FDCDevice::func_); \
 	phase_event->time = time_; \
 	scheduler->RestartEvent(phase_event); \
 } while (0)
@@ -104,7 +104,7 @@ FDCDevice::FDCDevice()
 	: inherited(OBJ_FDC)
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_FDC, this);
-	monitor->func = ToMonitorCallback(&FDCDevice::MonitorUpdate);
+	monitor->SetCallback(&FDCDevice::MonitorScreen);
 	// サイズは Create() 時に確定する
 }
 
@@ -414,7 +414,7 @@ FDCDevice::PokePort(uint32 offset, uint32 data)
 
 // モニタ更新
 void
-FDCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+FDCDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int x;
 	int y;
@@ -571,12 +571,12 @@ FDCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	for (int i = 0; i < fdd_vector.size(); i++) {
 		f = fdd_vector[i];
 		if (f) {
-			f->MonitorUpdateFDD(screen, hd);
+			f->MonitorScreenFDD(screen, hd);
 		}
 	}
 }
 
-// レジスタをビットごとに表示する。MonitorUpdate の下請け。
+// レジスタをビットごとに表示する。MonitorScreen の下請け。
 void
 FDCDevice::MonitorReg(TextScreen& screen,
 	int x, int y, uint8 reg, const char * const *names)
