@@ -377,7 +377,7 @@ class FDCDevice : public IODevice
 	// モータ停止用
 	void MotorEventCallback(Event *);
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 	void MonitorReg(TextScreen&,
 		int x, int y, uint8 reg, const char * const *names);
 
