@@ -156,7 +156,7 @@ FDDDevice::ResetHard(bool poweron)
 // y = 11 以降が各ドライブの状態で、このうち x = 26 以降が FDD の担当。
 // y = 16 以降は FDD のアクセスマップ。
 void
-FDDDevice::MonitorUpdateFDD(TextScreen& screen, uint hd)
+FDDDevice::MonitorScreenFDD(TextScreen& screen, uint hd)
 {
 /*        1         2         3         4         5         6         7
 0123456789012345678901234567890123456789012345678901234567890123456789012345678
