@@ -36,8 +36,8 @@ class GFPICDevice : public InterruptDevice
 	void RegistIRQ(int irq, const char *name, Device *source);
 
 	// Virt68kInterrupt の下請け
-	void MonitorUpdateSummary(TextScreen& screen, int x, int y);
-	int MonitorUpdateDetail(TextScreen& screen, int y, int lv);
+	void MonitorScreenSummary(TextScreen& screen, int x, int y);
+	int MonitorScreenDetail(TextScreen& screen, int y, int lv);
 
  protected:
 	// BusIO インタフェース
