@@ -22,6 +22,7 @@
 #include "goldfish_rtc.h"
 #include "event.h"
 #include "mpu.h"
+#include "mytime.h"
 #include "textscreen.h"
 
 //
@@ -75,10 +76,9 @@ GFRTCDevice::ReadPort(uint32 offset)
 					tm.tm_min,
 					tm.tm_sec);
 
-				struct timeval tv;
-				gettimeofday(&tv, NULL);
-				gmtime_r(&tv.tv_sec, &tr);
-				putlogn("gettimeofday: %4u/%02u/%02u %02u:%02u:%02u",
+				time_t u = (time_t)get_hosttime_sec();
+				gmtime_r(&u, &tr);
+				putlogn("system_clock: %4u/%02u/%02u %02u:%02u:%02u",
 					tr.tm_year + 1900,
 					tr.tm_mon + 1,
 					tr.tm_mday,
@@ -204,7 +204,7 @@ GFRTCDevice::PeekPort(uint32 offset)
 
 // モニタの下請け。(GFTimer から呼ばれる)
 int
-GFRTCDevice::MonitorUpdateRTC(TextScreen& screen, int y) const
+GFRTCDevice::MonitorScreenRTC(TextScreen& screen, int y) const
 {
 	screen.Puts(0, y++, "<RTC>");
 	screen.Print(0, y++, "%04u/%02u/%02u(%s) %02u:%02u:%02u",
