@@ -66,7 +66,7 @@ GFTimerDevice::GFTimerDevice()
 {
 	// モニタは GFRTC + GFTimer で共有。
 	monitor = gMonitorManager->Regist(ID_MONITOR_RTC, this);
-	monitor->func = ToMonitorCallback(&GFTimerDevice::MonitorUpdate);
+	monitor->SetCallback(&GFTimerDevice::MonitorScreen);
 	monitor->SetSize(38, 7);
 }
 
@@ -95,9 +95,9 @@ GFTimerDevice::Init()
 
 	// それによってイベントを分けてある。(time はどちらも都度セットする)
 	if (sync_rt) {
-		event->func = ToEventCallback(&GFTimerDevice::CallbackRT);
+		event->SetCallback(&GFTimerDevice::CallbackRT);
 	} else {
-		event->func = ToEventCallback(&GFTimerDevice::CallbackVT);
+		event->SetCallback(&GFTimerDevice::CallbackVT);
 	}
 
 	return true;
@@ -238,7 +238,7 @@ GFTimerDevice::PeekPort(uint32 offset)
 }
 
 void
-GFTimerDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+GFTimerDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int y = 0;
 
@@ -251,7 +251,7 @@ GFTimerDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	screen.Print(0, y++, "Alarm: %26s", TimeToStr(alarm).c_str());
 	y++;
 
-	gfrtc->MonitorUpdateRTC(screen, y);
+	gfrtc->MonitorScreenRTC(screen, y);
 }
 
 // 現在時刻を返す
