@@ -33,7 +33,7 @@ class GFTimerDevice : public IODevice
 	busdata PeekPort(uint32 offset);
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	void CallbackVT(Event *);
 	void CallbackRT(Event *);
