@@ -27,7 +27,7 @@ LanceDevice::LanceDevice()
 	AddAlias("Ethernet");
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_LANCE, this);
-	monitor->func = ToMonitorCallback(&LanceDevice::MonitorUpdate);
+	monitor->SetCallback(&LanceDevice::MonitorScreen);
 	monitor->SetSize(80, 34);
 }
 
@@ -137,7 +137,7 @@ LanceDevice::PeekPort(uint32 offset)
 }
 
 void
-LanceDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+LanceDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 /*
 CSR0: $1111 ERR  BABL CERR MISS MERR RINT TINT IDON   IADR:$123456
@@ -935,13 +935,13 @@ LanceDevice::ChangePhase(TXPhase new_phase, uint64 time)
 		scheduler->StopEvent(tx_event);
 		return;
 	 case TXPhase::IDLE:
-		tx_event->func = ToEventCallback(&LanceDevice::TXIdle);
+		tx_event->SetCallback(&LanceDevice::TXIdle);
 		break;
 	 case TXPhase::SEND:
-		tx_event->func = ToEventCallback(&LanceDevice::TXSend);
+		tx_event->SetCallback(&LanceDevice::TXSend);
 		break;
 	 case TXPhase::NEXT:
-		tx_event->func = ToEventCallback(&LanceDevice::TXNext);
+		tx_event->SetCallback(&LanceDevice::TXNext);
 		break;
 	 default:
 		assertmsg(false, "phase %u", (uint)new_phase);
@@ -1262,10 +1262,10 @@ LanceDevice::ChangePhase(RXPhase new_phase, uint64 time)
 		scheduler->StopEvent(rx_event);
 		return;
 	 case RXPhase::IDLE:
-		rx_event->func = ToEventCallback(&LanceDevice::RXIdle);
+		rx_event->SetCallback(&LanceDevice::RXIdle);
 		break;
 	 case RXPhase::NEXT:
-		rx_event->func = ToEventCallback(&LanceDevice::RXNext);
+		rx_event->SetCallback(&LanceDevice::RXNext);
 		break;
 	 default:
 		assertmsg(false, "phase %u", (uint)new_phase);
