@@ -182,7 +182,7 @@ class LanceDevice : public EthernetDevice, public IHWAddrFilter
 	busdata PeekPort(uint32 offset);
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 	void MonitorReg(TextScreen&,
 		int x, int y, uint32 data, const char * const * names);
 	uint32 ReadData();
