@@ -58,7 +58,7 @@ class LCDDevice : public Device
 	const uint8 *GetFont(uint ch) const;
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// 現在のアドレスでデータレジスタにラッチ
 	void LatchData();
