@@ -53,7 +53,7 @@ LunafbDevice::LunafbDevice()
 	AddAlias("Lunafb");
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_LUNAVC, this);
-	monitor->func = ToMonitorCallback(&LunafbDevice::MonitorUpdate);
+	monitor->SetCallback(&LunafbDevice::MonitorScreen);
 	monitor->SetSize(39, 11);
 }
 
@@ -291,7 +291,7 @@ LunafbDevice::Poke1(uint32 addr, uint32 data)
 }
 
 void
-LunafbDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+LunafbDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int i;
 
