@@ -123,8 +123,7 @@ MainbusDevice::MainbusDevice(uint objid_)
 	: inherited(objid_)
 {
 	accstat_monitor = gMonitorManager->Regist(ID_MONITOR_ACCSTAT, this);
-	accstat_monitor->func =
-		ToMonitorCallback(&MainbusDevice::MonitorUpdateAccStat);
+	accstat_monitor->SetCallback(&MainbusDevice::MonitorScreenAccStat);
 	// 表示行数が機種ごとに異なるので継承側でセットしている。
 
 	// 通常は 32bit 空間全体 (そうでない機種はコンストラクタで上書きする)
@@ -261,7 +260,7 @@ MainbusDevice::Peek4(uint32 addr)
 }
 
 void
-MainbusDevice::MonitorUpdateAccStat(Monitor *, TextScreen& screen)
+MainbusDevice::MonitorScreenAccStat(Monitor *, TextScreen& screen)
 {
 	std::array<char, 64 + 5> buf;
 
@@ -350,7 +349,7 @@ Mainbus24Device::Mainbus24Device()
 	: MainbusDevice(OBJ_MAINBUS)
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_MAINBUS, this);
-	monitor->func = ToMonitorCallback(&Mainbus24Device::MonitorUpdate);
+	monitor->SetCallback(&Mainbus24Device::MonitorScreen);
 	monitor->SetSize(75, 33);
 }
 
@@ -457,7 +456,7 @@ Mainbus24Device::Poke1(uint32 addr, uint32 data)
 }
 
 void
-Mainbus24Device::MonitorUpdate(Monitor *, TextScreen& screen)
+Mainbus24Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
