@@ -139,7 +139,7 @@ class MainbusDevice : public MainbusBaseDevice
 	uint64 Peek4(uint32 addr);
 
  protected:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateAccStat);
+	DECLARE_MONITOR_SCREEN(MonitorScreenAccStat);
 
 	// アクセス状況は 32bit 空間全域を 2048 * 2MB ずつ。
 	// (NEWS は読み出し時にマージする)
@@ -177,7 +177,7 @@ class Mainbus24Device : public MainbusDevice
 	bool Poke1(uint32 addr, uint32 data) override;
 
  protected:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	void InitAccStat();
 
