@@ -119,7 +119,7 @@ MFPDevice::MFPDevice()
 	: inherited(OBJ_MFP)
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_MFP, this);
-	monitor->func = ToMonitorCallback(&MFPDevice::MonitorUpdate);
+	monitor->SetCallback(&MFPDevice::MonitorScreen);
 	monitor->SetSize(77, 26);
 }
 
@@ -536,7 +536,7 @@ MFPDevice::PokePort(uint32 offset, uint32 data)
 }
 
 void
-MFPDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+MFPDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	MFP mfp_;
 	std::array<uint8, 4> tdr_;
