@@ -1103,7 +1103,7 @@ MPSCCDevice::GetParamStr(const MPSCCChan& chan) const
 // モニタに CR3/WR3、CR4/WR4、CR5/WR5 の内容を書き出す。
 // 更新後の y を返す。
 int
-MPSCCDevice::MonitorUpdateCR345(TextScreen& screen, int x, int y,
+MPSCCDevice::MonitorScreenCR345(TextScreen& screen, int x, int y,
 	uint8 cr3, uint8 cr4, uint8 cr5)
 {
 	const std::array<char, 4> bits_per_char { '5', '7', '6', '8' };
@@ -1158,7 +1158,7 @@ MPSCCDevice::MonitorUpdateCR345(TextScreen& screen, int x, int y,
 
 // モニタに SR1/RR1 の内容を書き出す。
 void
-MPSCCDevice::MonitorUpdateSR1(TextScreen& screen, int x, int y, uint8 sr1)
+MPSCCDevice::MonitorScreenSR1(TextScreen& screen, int x, int y, uint8 sr1)
 {
 	static const char * const sr1_str[] = {
 		"EOF", "FrEr", "RxOv", "PaEr", "", "", "", "Sent"
@@ -1167,7 +1167,7 @@ MPSCCDevice::MonitorUpdateSR1(TextScreen& screen, int x, int y, uint8 sr1)
 	screen.Print(x + 29, y, TA::Disable, "ResidueCode=%d", (sr1 >> 1) & 7);
 }
 
-// レジスタをビットごとに表示する。MonitorUpdate の下請け。
+// レジスタをビットごとに表示する。MonitorScreen の下請け。
 void
 MPSCCDevice::MonitorReg(TextScreen& screen,
 	int x, int y, uint32 reg, const char * const *names)
