@@ -592,8 +592,8 @@ class MPSCCDevice : public IODevice
 	int GetStopBits(MPSCCChan&, bool enable);
 
 	// モニタの下請け
-	int MonitorUpdateCR345(TextScreen&, int x, int y, uint8, uint8, uint8);
-	void MonitorUpdateSR1(TextScreen&, int x, int y, uint8 sr1);
+	int MonitorScreenCR345(TextScreen&, int x, int y, uint8, uint8, uint8);
+	void MonitorScreenSR1(TextScreen&, int x, int y, uint8 sr1);
 	void MonitorReg(TextScreen&, int x, int y,
 		uint32 reg, const char * const *names);
 
