@@ -133,7 +133,7 @@ void
 MainMPUDevice::ChangeState(uint32 new_state)
 {
 	// new_mode (CPU_STATE_*) と
-	// RequestCPUMode() の引数 Syncer::SYNCMODE_CPU_* は
+	// NotifyCPUMode() の引数 Syncer::SYNCMODE_CPU_* は
 	// 実は同じ値なのでそのまま渡してよいことにする。
 	static_assert(CPU_STATE_NORMAL == Syncer::SYNCMODE_CPU_NORMAL, "");
 	static_assert(CPU_STATE_STOP   == Syncer::SYNCMODE_CPU_STOP,   "");
@@ -142,7 +142,7 @@ MainMPUDevice::ChangeState(uint32 new_state)
 	if (cpu_state != new_state) {
 		cpu_state = new_state;
 		// スケジューラに通知
-		syncer->RequestCPUMode(cpu_state);
+		syncer->NotifyCPUMode(cpu_state);
 	}
 }
 
