@@ -29,17 +29,17 @@ MPU64180Device::MPU64180Device()
 
 	// レジスタモニター
 	reg_monitor = gMonitorManager->Regist(ID_MONITOR_XPREG, this);
-	reg_monitor->func = ToMonitorCallback(&MPU64180Device::MonitorUpdateReg);
+	reg_monitor->SetCallback(&MPU64180Device::MonitorScreenReg);
 	reg_monitor->SetSize(38, 6);
 
 	// I/O モニター
 	io_monitor = gMonitorManager->Regist(ID_MONITOR_XPIO, this);
-	io_monitor->func = ToMonitorCallback(&MPU64180Device::MonitorUpdateIO);
+	io_monitor->SetCallback(&MPU64180Device::MonitorScreenIO);
 	io_monitor->SetSize(55, 20);
 
 	// 割り込みモニター
 	intr_monitor = gMonitorManager->Regist(ID_MONITOR_XPINTR, this);
-	intr_monitor->func = ToMonitorCallback(&MPU64180Device::MonitorUpdateIntr);
+	intr_monitor->SetCallback(&MPU64180Device::MonitorScreenIntr);
 	intr_monitor->SetSize(64, 18);
 }
 
@@ -336,8 +336,9 @@ MPU64180Device::SetExec(EventCallback_t new_exec)
 {
 	exec_func = new_exec;
 
-	if (exec_event->func != ToEventCallback(&MPU64180Device::ExecTrace)) {
-		exec_event->func = exec_func;
+	auto execTrace = ToEventCallback(&MPU64180Device::ExecTrace);
+	if (exec_event->GetCallback() != execTrace) {
+		exec_event->SetCallback(exec_func);
 	}
 }
 
@@ -345,14 +346,11 @@ MPU64180Device::SetExec(EventCallback_t new_exec)
 void
 MPU64180Device::SetTrace(bool enable)
 {
-	EventCallback_t func;
-
 	if (enable) {
-		func = ToEventCallback(&MPU64180Device::ExecTrace);
+		exec_event->SetCallback(&MPU64180Device::ExecTrace);
 	} else {
-		func = exec_func;
+		exec_event->SetCallback(exec_func);
 	}
-	exec_event->func = func;
 }
 
 // IX/IY 分を考慮したサイクル数
@@ -487,7 +485,7 @@ MPU64180Device::SetSYSCALLCallback(void (*callback)(void *), void *arg)
 }
 
 void
-MPU64180Device::MonitorUpdateReg(Monitor *, TextScreen& screen)
+MPU64180Device::MonitorScreenReg(Monitor *, TextScreen& screen)
 {
 	screen.Clear();
 
@@ -541,7 +539,7 @@ MPU64180Device::opmode_names[] = {
 };
 
 void
-MPU64180Device::MonitorUpdateIO(Monitor *, TextScreen& screen)
+MPU64180Device::MonitorScreenIO(Monitor *, TextScreen& screen)
 {
 	int y;
 	uint32 val;
@@ -631,7 +629,7 @@ MPU64180Device::MonitorUpdateIO(Monitor *, TextScreen& screen)
 }
 
 void
-MPU64180Device::MonitorUpdateIntr(Monitor *, TextScreen& screen)
+MPU64180Device::MonitorScreenIntr(Monitor *, TextScreen& screen)
 {
 	static const struct {
 		uint offset;
