@@ -214,7 +214,7 @@ MPU680x0Device::ResetHard(bool poweron)
 	// SP, PC をフェッチするという順序にしないといけないため、リセット例外が
 	// 起動するまでに時間がかかるというところを都合よく真似ておく。
 
-	exec_event->func = ToEventCallback(&MPU680x0Device::ResetCallback);
+	exec_event->SetCallback(&MPU680x0Device::ResetCallback);
 	exec_event->time = 520 * clock_nsec;
 	exec_event->SetName(GetName() + " Reset");
 	scheduler->RestartEvent(exec_event);
@@ -237,7 +237,7 @@ MPU680x0Device::ResetCallback(Event *ev)
 
 	// 以降は通常走行。
 	if (cpu_state == CPU_STATE_NORMAL) {
-		exec_event->func = exec_short;
+		exec_event->SetCallback(exec_short);
 		exec_event->time = cycle * clock_nsec;
 		exec_event->SetName(GetName() + " Execute");
 		scheduler->RestartEvent(exec_event);
@@ -277,7 +277,7 @@ MPU680x0Device::ExecFull(Event *ev)
 	} else {
 		if (cpu_state == CPU_STATE_NORMAL) {
 			// コールバックを通常処理に戻してから...
-			exec_event->func = exec_short;
+			exec_event->SetCallback(exec_short);
 
 			// この場で次の命令を実行。
 			ExecShort(ev);
@@ -306,7 +306,7 @@ MPU680x0Device::SetTrace(bool enable)
 		exec_short = ToEventCallback(&MPU680x0Device::ExecShort);
 		exec_full  = ToEventCallback(&MPU680x0Device::ExecFull);
 	}
-	exec_event->func = exec_full;
+	exec_event->SetCallback(exec_full);
 
 	// STOP 命令中にオンにするには、停止しているイベントを起こす。
 	// STOP 命令中にオフにする場合は、何もしなくていい。
@@ -378,7 +378,7 @@ MPU680x0Device::InterruptCallback(Event *ev)
 void
 MPU680x0Device::MakeNextFull()
 {
-	exec_event->func = exec_full;
+	exec_event->SetCallback(exec_full);
 }
 
 // A-Line 命令エミュレーションのコールバックを指定。
@@ -422,7 +422,7 @@ MPU680x0Device::Halt()
 
 // モニター更新の下請け (レジスタ共通部分)
 void
-MPU680x0Device::MonitorUpdateRegCommon(TextScreen& screen,
+MPU680x0Device::MonitorScreenRegCommon(TextScreen& screen,
 	m68kreg& tmp, uint32 tmp_ppc, uint32 tmp_state)
 {
 	int x;
@@ -490,7 +490,7 @@ MPU680x0Device::MonitorUpdateRegCommon(TextScreen& screen,
 
 // モニタ更新の下請け (FPU)
 int
-MPU680x0Device::MonitorUpdateFPU(TextScreen& screen, int y, m68kreg& tmp)
+MPU680x0Device::MonitorScreenFPU(TextScreen& screen, int y, m68kreg& tmp)
 {
 	int x;
 
@@ -586,17 +586,16 @@ MPU68030Device::MPU68030Device()
 
 	// レジスタモニター (サイズは Init で確定する)
 	reg_monitor = gMonitorManager->Regist(ID_MONITOR_MPUREG, this);
-	reg_monitor->func = ToMonitorCallback(&MPU68030Device::MonitorUpdateReg);
+	reg_monitor->SetCallback(&MPU68030Device::MonitorScreenReg);
 
 	// ATC モニター
 	atc_monitor = gMonitorManager->Regist(ID_MONITOR_MPUATC, this);
-	atc_monitor->func = ToMonitorCallback(&MPU68030Device::MonitorUpdateATC);
+	atc_monitor->SetCallback(&MPU68030Device::MonitorScreenATC);
 	atc_monitor->SetSize(114, m68030ATCTable::LINES + 6);
 
 	// キャッシュモニター
 	cache_monitor = gMonitorManager->Regist(ID_MONITOR_MPUCACHE, this);
-	cache_monitor->func =
-		ToMonitorCallback(&MPU68030Device::MonitorUpdateCache);
+	cache_monitor->SetCallback(&MPU68030Device::MonitorScreenCache);
 	cache_monitor->SetSize(48, 20 * 2 + 1);
 }
 
@@ -623,7 +622,7 @@ sort_atc(const void *a, const void *b)
 
 // モニター更新 (レジスタ)
 void
-MPU68030Device::MonitorUpdateReg(Monitor *, TextScreen& screen)
+MPU68030Device::MonitorScreenReg(Monitor *, TextScreen& screen)
 {
 	m68kreg tmp;
 	uint32 tmp_ppc;
@@ -639,21 +638,21 @@ MPU68030Device::MonitorUpdateReg(Monitor *, TextScreen& screen)
 	tmp_state = cpu_state;
 
 	// 共通部分。
-	MonitorUpdateRegCommon(screen, tmp, tmp_ppc, tmp_state);
+	MonitorScreenRegCommon(screen, tmp, tmp_ppc, tmp_state);
 
 	// Cache/MMU 部分。
 	y = 4;
-	y = MonitorUpdateMMU(screen, y, tmp);
+	y = MonitorScreenMMU(screen, y, tmp);
 
 	// FPU はある時だけ表示。
 	if (HasFPU()) {
-		MonitorUpdateFPU(screen, y, tmp);
+		MonitorScreenFPU(screen, y, tmp);
 	}
 }
 
 // モニター更新の下請け (Cache/MMU 部分)
 int
-MPU68030Device::MonitorUpdateMMU(TextScreen& screen, int y, m68kreg& tmp)
+MPU68030Device::MonitorScreenMMU(TextScreen& screen, int y, m68kreg& tmp)
 {
 	int x;
 
@@ -727,7 +726,7 @@ MPU68030Device::MonitorUpdateMMU(TextScreen& screen, int y, m68kreg& tmp)
 
 // モニター更新 (68030 ATC)
 void
-MPU68030Device::MonitorUpdateATC(Monitor *, TextScreen& screen)
+MPU68030Device::MonitorScreenATC(Monitor *, TextScreen& screen)
 {
 	m68030ATCTable *table;
 
@@ -875,7 +874,7 @@ dcache_fc2str(const m68030CacheLine& l)
 
 // モニタ更新 (68030 キャッシュ)
 void
-MPU68030Device::MonitorUpdateCache(Monitor *, TextScreen& screen)
+MPU68030Device::MonitorScreenCache(Monitor *, TextScreen& screen)
 {
 	int y;
 
@@ -888,16 +887,16 @@ MPU68030Device::MonitorUpdateCache(Monitor *, TextScreen& screen)
 
 	y = 0;
 	screen.Puts(0, y++, "<Instruction Cache>");
-	y = MonitorUpdateCache1(screen, y, icache.get(), icache_fc2str);
+	y = MonitorScreenCache1(screen, y, icache.get(), icache_fc2str);
 
 	y++;
 	screen.Puts(0, y++, "<Data Cache>");
-	MonitorUpdateCache1(screen, y, dcache.get(), dcache_fc2str);
+	MonitorScreenCache1(screen, y, dcache.get(), dcache_fc2str);
 }
 
 // モニタ更新 (68030 キャッシュ片方の下請け)
 int
-MPU68030Device::MonitorUpdateCache1(TextScreen& screen, int y,
+MPU68030Device::MonitorScreenCache1(TextScreen& screen, int y,
 	m68030Cache *cache, char (*fc2str)(const m68030CacheLine&))
 {
 	screen.Puts(0, y, "Tag Address  Data[0]");
@@ -967,11 +966,11 @@ MPU68040Device::MPU68040Device()
 
 	// レジスタモニター (サイズは Init で確定する)
 	reg_monitor = gMonitorManager->Regist(ID_MONITOR_MPUREG, this);
-	reg_monitor->func = ToMonitorCallback(&MPU68040Device::MonitorUpdateReg);
+	reg_monitor->SetCallback(&MPU68040Device::MonitorScreenReg);
 
 	// ATC モニター (Inst/Data)
 	atc_monitor = gMonitorManager->Regist(ID_MONITOR_MPUATC, this);
-	atc_monitor->func = ToMonitorCallback(&MPU68040Device::MonitorUpdateATC);
+	atc_monitor->SetCallback(&MPU68040Device::MonitorScreenATC);
 	atc_monitor->SetSize(125, 34);
 }
 
@@ -982,7 +981,7 @@ MPU68040Device::~MPU68040Device()
 
 // モニター更新 (レジスタ)
 void
-MPU68040Device::MonitorUpdateReg(Monitor *, TextScreen& screen)
+MPU68040Device::MonitorScreenReg(Monitor *, TextScreen& screen)
 {
 	m68kreg tmp;
 	uint32 tmp_ppc;
@@ -1000,22 +999,22 @@ MPU68040Device::MonitorUpdateReg(Monitor *, TextScreen& screen)
 	tmp_fpu40 = fpu40;
 
 	// 共通部分。
-	MonitorUpdateRegCommon(screen, tmp, tmp_ppc, tmp_state);
+	MonitorScreenRegCommon(screen, tmp, tmp_ppc, tmp_state);
 
 	// Cache/MMU 部分。
 	y = 4;
-	y = MonitorUpdateMMU(screen, y, tmp);
+	y = MonitorScreenMMU(screen, y, tmp);
 
 	// FPU はある時だけ表示。
 	if (HasFPU()) {
-		y = MonitorUpdateFPU(screen, y, tmp);
-		MonitorUpdateFPU40(screen, y, tmp_fpu40);
+		y = MonitorScreenFPU(screen, y, tmp);
+		MonitorScreenFPU40(screen, y, tmp_fpu40);
 	}
 }
 
 // モニター更新の下請け (Cache/MMU 部分)
 int
-MPU68040Device::MonitorUpdateMMU(TextScreen& screen, int y, m68kreg& tmp)
+MPU68040Device::MonitorScreenMMU(TextScreen& screen, int y, m68kreg& tmp)
 {
 	int x;
 
@@ -1052,17 +1051,17 @@ MPU68040Device::MonitorUpdateMMU(TextScreen& screen, int y, m68kreg& tmp)
 
 	y -= 4;
 	x = 33;
-	MonitorUpdateTT(screen, x, y++, "ITT0", tmp.itt[0]);
-	MonitorUpdateTT(screen, x, y++, "ITT1", tmp.itt[1]);
-	MonitorUpdateTT(screen, x, y++, "DTT0", tmp.dtt[0]);
-	MonitorUpdateTT(screen, x, y++, "DTT1", tmp.dtt[1]);
+	MonitorScreenTT(screen, x, y++, "ITT0", tmp.itt[0]);
+	MonitorScreenTT(screen, x, y++, "ITT1", tmp.itt[1]);
+	MonitorScreenTT(screen, x, y++, "DTT0", tmp.dtt[0]);
+	MonitorScreenTT(screen, x, y++, "DTT1", tmp.dtt[1]);
 
 	return y;
 }
 
 // *TTn 1つ分の下請け。
 void
-MPU68040Device::MonitorUpdateTT(TextScreen& screen, int x, int y,
+MPU68040Device::MonitorScreenTT(TextScreen& screen, int x, int y,
 	const char *name, uint32 tt)
 {
 	bool e = (tt & m68040TT::E);
