@@ -447,8 +447,8 @@ class MPU680x0Device : public MainMPUDevice
 	EventCallback_t exec_full {};
 
 	// モニター
-	void MonitorUpdateRegCommon(TextScreen&, m68kreg&, uint32, uint32);
-	int  MonitorUpdateFPU(TextScreen&, int y, m68kreg&);
+	void MonitorScreenRegCommon(TextScreen&, m68kreg&, uint32, uint32);
+	int  MonitorScreenFPU(TextScreen&, int y, m68kreg&);
 	Monitor *reg_monitor {};
 	Monitor *atc_monitor {};
 	Monitor *cache_monitor {};
@@ -532,11 +532,11 @@ class MPU68030Device : public MPU680x0Device
 	m68030ATC atc {this};
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateReg);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateATC);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateCache);
-	int MonitorUpdateMMU(TextScreen&, int, m68kreg&);
-	int MonitorUpdateCache1(TextScreen&, int y, m68030Cache *,
+	DECLARE_MONITOR_SCREEN(MonitorScreenReg);
+	DECLARE_MONITOR_SCREEN(MonitorScreenATC);
+	DECLARE_MONITOR_SCREEN(MonitorScreenCache);
+	int MonitorScreenMMU(TextScreen&, int, m68kreg&);
+	int MonitorScreenCache1(TextScreen&, int y, m68030Cache *,
 		char (*)(const m68030CacheLine&));
 
 	// キャッシュ
@@ -598,14 +598,14 @@ class MPU68040Device : public MPU680x0Device
 	// MMU 有効状態を更新。(TC と *TTn の変更で呼ばれる)
 	void mmu_enable_changed();
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateReg);
-	DECLARE_MONITOR_CALLBACK(MonitorUpdateATC);
-	int MonitorUpdateMMU(TextScreen&, int, m68kreg&);
-	void MonitorUpdateTT(TextScreen&, int x, int y, const char *, uint32);
-	void MonitorUpdateATC1(TextScreen&, int, const m68040ATC *);
+	DECLARE_MONITOR_SCREEN(MonitorScreenReg);
+	DECLARE_MONITOR_SCREEN(MonitorScreenATC);
+	int MonitorScreenMMU(TextScreen&, int, m68kreg&);
+	void MonitorScreenTT(TextScreen&, int x, int y, const char *, uint32);
+	void MonitorScreenATC1(TextScreen&, int, const m68040ATC *);
 
 	// FPU
-	void MonitorUpdateFPU40(TextScreen&, int y, const FPU40&);
+	void MonitorScreenFPU40(TextScreen&, int y, const FPU40&);
 	static std::string GetReg1BName(uint32 opclass, uint32 sz, uint32 cmd);
 	static std::string GetFPUTagName(int32);
 
