@@ -54,7 +54,7 @@ MPU88xx0Device::MPU88xx0Device()
 
 	// レジスタモニター
 	monitor = gMonitorManager->Regist(ID_MONITOR_MPUREG, this);
-	monitor->func = ToMonitorCallback(&MPU88xx0Device::MonitorUpdate);
+	monitor->SetCallback(&MPU88xx0Device::MonitorScreen);
 	monitor->SetSize(79, 25);
 }
 
@@ -147,7 +147,7 @@ MPU88xx0Device::ResetHard(bool poweron)
 	// リセット例外が起動するまでに時間がかかるというところを都合よく真似て
 	// おく。
 
-	exec_event->func = ToEventCallback(&MPU88xx0Device::ResetCallback);
+	exec_event->SetCallback(&MPU88xx0Device::ResetCallback);
 	exec_event->time = (8 + 256) * clock_nsec;
 	exec_event->SetName(GetName() + " Reset");
 	scheduler->RestartEvent(exec_event);
@@ -217,7 +217,7 @@ MPU88xx0Device::ResetCallback(Event *ev)
 
 	// 以降は通常走行
 	int cycle = used_cycle - cycle_start;
-	exec_event->func = exec_normal;
+	exec_event->SetCallback(exec_normal);
 	exec_event->time = cycle * clock_nsec;
 	exec_event->SetName(GetName() + " Execute");
 	scheduler->StartEvent(exec_event);
@@ -240,7 +240,7 @@ MPU88xx0Device::SetTrace(bool enable)
 	} else {
 		exec_normal = ToEventCallback(&MPU88xx0Device::ExecNormal);
 	}
-	exec_event->func = exec_normal;
+	exec_event->SetCallback(exec_normal);
 }
 
 // アクセス中の論理アドレスを取得
@@ -315,7 +315,7 @@ MPU88xx0Device::SetFLineCallback(bool (*callback)(MPU88xx0Device *, void *),
 
 // モニター更新
 void
-MPU88xx0Device::MonitorUpdate(Monitor *, TextScreen& screen)
+MPU88xx0Device::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	m88100reg tmp;
 	int x;
