@@ -42,7 +42,7 @@ class NewsCtlrDevice : public IODevice
 
 	uint GetLED() const { return led; }
 
-	void MonitorUpdateNewsCtlr(TextScreen& screen, int y);
+	void MonitorScreenNewsCtlr(TextScreen& screen, int y);
 
  private:
 	uint8 GetIDROM(uint32 addr) const;
