@@ -25,7 +25,7 @@ class NewsfbDevice : public Device
 	void Putc(int ch);
 
  private:
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	TextScreen console {};
 
