@@ -34,7 +34,7 @@ class NewsIODevice : public IODevice
 	inline IODevice *SearchDevice(uint32 addr) const;
 
 	void InitMonitor();
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	std::unique_ptr<IODevice> pKBC {};
 	std::unique_ptr<IODevice> pLance {};
