@@ -45,7 +45,7 @@ class i8255Device : public IODevice
 	virtual void SetPC(uint, uint) = 0;
 
 	// 共通部分
-	int MonitorUpdateCommon(TextScreen& screen, int y);
+	int MonitorScreenCommon(TextScreen& screen, int y);
 
 	// 7  6  5  4  3   2  1  0
 	// 1  AM AM AD CHD BM BD CLD
@@ -134,7 +134,7 @@ class PIO0Device : public i8255Device
 	void SetPC(uint, uint) override;
 	void ChangeInterrupt();
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	bool dipsw1[8] {};
 	bool dipsw2[8] {};
@@ -161,7 +161,7 @@ class PIO1Device : public i8255Device
 	void ResetHard(bool poweron) override;
 
 	// PIO0 の下請け
-	void MonitorUpdatePIO1(TextScreen& screen, int y);
+	void MonitorScreenPIO1(TextScreen& screen, int y);
 
 	// BusIO インタフェース
 	// (内蔵 ROM からのアクセス用に特別に public にしてある)
@@ -175,7 +175,7 @@ class PIO1Device : public i8255Device
 	uint32 GetPC() const;
 	void SetPC(uint, uint) override;
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	bool power {};			// パワーダウン (false で電源オフ指示)
 	bool xp_intreq {};		// XP 割り込み要求。あり(true)なら %0
