@@ -77,7 +77,7 @@ class VideoRenderer : public ThreadDevice
 
 	void PrintPerf();
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// ウィンドウとして表示される画面はオプションや設定などで縮尺を変える
 	// ことが出来るが (こっちを実画面とする)、ここで扱う仮想画面とはそれに
