@@ -11,6 +11,7 @@
 #include "rtc.h"
 #include "config.h"
 #include "event.h"
+#include "mytime.h"
 #include "scheduler.h"
 #include "syncer.h"
 
@@ -94,7 +95,8 @@ RTCDevice::Init()
 void
 RTCDevice::StartTime()
 {
-	struct timeval tv;
+	time_t now_sec;
+	uint64 now_usec;
 	struct tm tm;
 
 	if (force_fixed) {
@@ -107,17 +109,19 @@ RTCDevice::StartTime()
 			.tm_mon = 7 - 1,
 			.tm_year = 2018 - 1900,
 		};
-		tv.tv_sec = timegm(&fixed);
-		tv.tv_usec = 0;
+		now_sec = timegm(&fixed);
+		now_usec = 0;
 	} else {
 		// 起動した時の現在時刻で設定する
-		gettimeofday(&tv, NULL);
+		auto usec = get_hosttime_usec();
+		now_sec  = usec / 1000'000U;
+		now_usec = usec % 1000'000U;
 	}
 
 	if (use_localtime) {
-		localtime_r(&tv.tv_sec, &tm);
+		localtime_r(&now_sec, &tm);
 	} else {
-		gmtime_r(&tv.tv_sec, &tm);
+		gmtime_r(&now_sec, &tm);
 	}
 
 	// 日付、時刻の直接指定があればここで差し替える。
@@ -136,7 +140,7 @@ RTCDevice::StartTime()
 	}
 
 	// 秒未満の初期値もそれなりの精度にしておく (1000*1000 / 32 = 31250)
-	cnt = tv.tv_usec / 31250;
+	cnt = now_usec / 31250;
 	SetSec(tm.tm_sec);
 	SetMin(tm.tm_min);
 	SetHour(tm.tm_hour);
