@@ -56,7 +56,7 @@ RTL8019ASDevice::RTL8019ASDevice(uint n, int vector_)
 	intr_vector = vector_;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_RTL8019AS(n), this);
-	monitor->func = ToMonitorCallback(&RTL8019ASDevice::MonitorUpdate);
+	monitor->SetCallback(&RTL8019ASDevice::MonitorScreen);
 	monitor->SetSize(71, 19);
 }
 
@@ -309,7 +309,7 @@ RTL8019ASDevice::Peek1(uint32 addr)
 }
 
 void
-RTL8019ASDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+RTL8019ASDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	uint32 val;
 	const int x = 6;
@@ -546,7 +546,7 @@ RTL8019ASDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	screen.Print(x2, y++, "CNTR2 =  $%02x", PeekCNTR(2));
 }
 
-// レジスタをビットごとに表示する。MonitorUpdate の下請け。
+// レジスタをビットごとに表示する。MonitorScreen の下請け。
 // "-" で始まっていたら Disable 色にし、次の文字から表示。
 void
 RTL8019ASDevice::MonitorReg(TextScreen& screen,
