@@ -339,7 +339,7 @@ class RTL8019ASDevice : public EthernetDevice, public IHWAddrFilter
 	uint32 PeekINTR() const;
 	uint32 PeekDMA(uint32 a0) const;
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 	void MonitorReg(TextScreen&, int, int, uint32, const char * const *names);
 
 	void Reset();
