@@ -57,7 +57,7 @@ SCCDevice::SCCDevice()
 	}
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SCC, this);
-	monitor->func = ToMonitorCallback(&SCCDevice::MonitorUpdate);
+	monitor->SetCallback(&SCCDevice::MonitorScreen);
 	monitor->SetSize(70, 35);
 }
 
@@ -749,7 +749,7 @@ SCCDevice::WriteWR15(MPSCCChan& chan, uint32 data)
 
 // モニター
 void
-SCCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+SCCDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	uint wr9;
 	uint rr3a;
@@ -762,7 +762,7 @@ SCCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	for (int i = 0; i < 2; i++) {
 		int x = 0;
 		y = i * 16;
-		MonitorUpdateCh(screen, i, x, y);
+		MonitorScreenCh(screen, i, x, y);
 	}
 
 	y = 32;
@@ -797,7 +797,7 @@ SCCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 
 // モニター (1チャンネル)
 void
-SCCDevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
+SCCDevice::MonitorScreenCh(TextScreen& screen, int ch, int xbase, int ybase)
 {
 	const MPSCCChan& chan = mpscc.chan[ch];
 	uint crc;
@@ -911,7 +911,7 @@ SCCDevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
 	y++;
 
 	// WR3,WR4,WR5
-	y = MonitorUpdateCR345(screen, x, y, wr3, wr4, wr5);
+	y = MonitorScreenCR345(screen, x, y, wr3, wr4, wr5);
 
 	// WR10
 	screen.Puts(x +  9, y, TA::Disable, (wr10 & 0x80) ? "CRC1" : "CRC0");
@@ -989,7 +989,7 @@ SCCDevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
 	y++;
 
 	// RR1
-	MonitorUpdateSR1(screen, x, y, rr1);
+	MonitorScreenSR1(screen, x, y, rr1);
 	y++;
 
 	// RR10
