@@ -85,7 +85,7 @@ class Scheduler : public ThreadDevice
 	void DispatchMessage();
 	void InvokeMessage(MessageID, uint32);
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// 有効なイベントキュー
 	uint64 slow_top_vtime {};
