@@ -101,7 +101,7 @@
 // time 時間後に呼び出すコールバックをセットする。
 // func の書式が面倒なのを省略して書きたいため。
 #define CallAfter(func_, name_, time_)	do { \
-	event->func = ToEventCallback(&SCSIBus::func_); \
+	event->SetCallback(&SCSIBus::func_); \
 	event->time = time_; \
 	event->SetName(name_); \
 	scheduler->RestartEvent(event); \
