@@ -20,6 +20,7 @@
 #include "scsidev.h"
 #include "scsidomain.h"
 #include "config.h"
+#include "event.h"
 #include "mainapp.h"
 #include "scheduler.h"
 #include "uimessage.h"
@@ -61,6 +62,7 @@ SCSIHostDevice::SCSIHostDevice(SCSIDomain *domain_, IODevice *parent_)
 	// イニシエータの ID は実行時にコントローラによって決まる。
 	devtype = SCSI::DevType::Initiator;
 
+	SetName(string_format("(SCSIHost.%s)", domain_->GetConfigName()));
 	SetLogLevel(parent->loglevel);
 }
 
@@ -158,6 +160,8 @@ SCSITarget::SCSITarget(SCSIDomain *domain_, uint id)
 {
 	domain = domain_;
 	myid = id;
+
+	// ログは出すので名前はつけるがそれは継承先で SetName() している。
 }
 
 // デストラクタ
@@ -650,10 +654,6 @@ SCSIDisk::Init()
 		if (LoadDisk(path) == false) {
 			return false;
 		}
-	} else {
-		// メディアがロードされないままでも起動時は必ず通知を投げる。
-		// ステータスパネルはこの UIMessage でのみ状態を更新するため。
-		MediaChanged();
 	}
 
 	// 平均シークタイム。設定は [msec]、変数は [nsec]。
@@ -881,7 +881,7 @@ SCSIDisk::Clear()
 void
 SCSIDisk::MediaChanged() const
 {
-	UIMessage::Post(UIMessage::SCSI_MEDIA_CHANGE, GetMyID());
+	gMainApp.GetUIMessage()->Post(UIMessage::SCSI_MEDIA_CHANGE, GetMyID());
 }
 
 // メディアを挿入する。
@@ -907,7 +907,7 @@ SCSIDisk::LoadMessage(MessageID msgid, uint32 arg)
 {
 	if (LoadDisk(new_pathname) == false) {
 		// 失敗したら UI に通知
-		UIMessage::Post(UIMessage::SCSI_MEDIA_FAILED);
+		gMainApp.GetUIMessage()->Post(UIMessage::SCSI_MEDIA_FAILED);
 	}
 }
 
