@@ -49,7 +49,7 @@ SIODevice::SIODevice()
 	mpscc.chan[1].xc12_ns = 78.125_usec;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SIO, this);
-	monitor->func = ToMonitorCallback(&SIODevice::MonitorUpdate);
+	monitor->SetCallback(&SIODevice::MonitorScreen);
 	monitor->SetSize(70, 24);
 }
 
@@ -603,7 +603,7 @@ SIODevice::SetVIS()
 
 // モニター
 void
-SIODevice::MonitorUpdate(Monitor *, TextScreen& screen)
+SIODevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	uint cr2a;
 	uint cr2b;
@@ -618,7 +618,7 @@ SIODevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	for (int i = 0; i < 2; i++) {
 		int x = 0;
 		y = i * 11;
-		MonitorUpdateCh(screen, i, x, y);
+		MonitorScreenCh(screen, i, x, y);
 	}
 
 	// CR2A
@@ -647,7 +647,7 @@ SIODevice::MonitorUpdate(Monitor *, TextScreen& screen)
 
 // モニター (1チャンネル)
 void
-SIODevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
+SIODevice::MonitorScreenCh(TextScreen& screen, int ch, int xbase, int ybase)
 {
 	const MPSCCChan& chan = mpscc.chan[ch];
 	uint cr0;
@@ -750,7 +750,7 @@ SIODevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
 	y++;
 
 	// CR3,CR4,CR5
-	y = MonitorUpdateCR345(screen, x, y, cr3, cr4, cr5);
+	y = MonitorScreenCR345(screen, x, y, cr3, cr4, cr5);
 
 	// CR6,CR7
 	y++;
@@ -767,7 +767,7 @@ SIODevice::MonitorUpdateCh(TextScreen& screen, int ch, int xbase, int ybase)
 	y++;
 
 	// SR1
-	MonitorUpdateSR1(screen, x, y, sr1);
+	MonitorScreenSR1(screen, x, y, sr1);
 	y++;
 
 	// 右列
