@@ -21,7 +21,7 @@
 // time 時間後に呼び出すコールバックをセットする。
 // func の書式が面倒なのを省略して書きたいため。
 #define CallAfter(func_, name_, time_)	do { \
-	phase_event->func = ToEventCallback(&SPCDevice::func_); \
+	phase_event->SetCallback(&SPCDevice::func_); \
 	phase_event->time = time_; \
 	phase_event->SetName(name_); \
 	scheduler->RestartEvent(phase_event); \
@@ -35,7 +35,7 @@ SPCDevice::SPCDevice()
 	myid = 7;
 
 	monitor = gMonitorManager->Regist(ID_MONITOR_SPC, this);
-	monitor->func = ToMonitorCallback(&SPCDevice::MonitorUpdate);
+	monitor->SetCallback(&SPCDevice::MonitorScreen);
 	// サイズは Init で決まる
 }
 
@@ -488,7 +488,7 @@ SPCDevice::PokePort(uint32 offset, uint32 data)
 }
 
 void
-SPCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
+SPCDevice::MonitorScreen(Monitor *, TextScreen& screen)
 {
 	int x;
 	int y;
@@ -651,9 +651,10 @@ SPCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	y = 2;
 	screen.Puts(x + 4, y++, "(________)");
 	screen.Puts(x + 4, y++, "(________)");
-	screen.Puts(x + 4, y++, "+");
-	screen.Puts(x + 4, y++, "|");
-	screen.Puts(x + 4, y++, "+");
+	// Shift-JIS は手動で置く必要がある。
+	screen.Puts(x + 4, y++, "\x84\xa2");	// "┐"
+	screen.Puts(x + 4, y++, "\x84\xa0");	// "│"
+	screen.Puts(x + 4, y++, "\x84\xa3");	// "┘"
 
 	// BSY, SEL の内訳。"(76543210)" の順。
 	y = 2;
@@ -675,9 +676,9 @@ SPCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 
 	// 転送フェーズ中なら現在の XferPhase
 	y += 2;
-	if (ph == SCSI::Phase::Transfer) {
-		screen.Puts(x + 5, y, SCSI::GetXferPhaseName(GetXfer()));
-	}
+	TA attrxfer = (ph == SCSI::Phase::Transfer) ? TA::Normal : TA::Disable;
+	screen.Puts(x + 6, y++, attrxfer, "XferPhase:");
+	screen.Puts(x + 6, y,   attrxfer, SCSI::GetXferPhaseName(GetXfer()));
 
 	// デバイス一覧
 	// 0         1
@@ -733,7 +734,7 @@ SPCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	}
 }
 
-// レジスタをビットごとに表示する。MonitorUpdate の下請け。
+// レジスタをビットごとに表示する。MonitorScreen の下請け。
 void
 SPCDevice::MonitorReg(TextScreen& screen,
 	int x, int y, uint32 reg, const char * const *names)
@@ -890,8 +891,7 @@ SPCDevice::WriteINTS(uint32 data)
 			if (spc.tc == 0) {
 				BusFree();
 			} else {
-				timer_event->func =
-					ToEventCallback(&SPCDevice::SelectionTimeout);
+				timer_event->SetCallback(&SPCDevice::SelectionTimeout);
 				timer_event->time = spc.tc * t_CLF * 2;
 				scheduler->RestartEvent(timer_event);
 			}
@@ -1264,7 +1264,7 @@ SPCDevice::SelectCommand()
 	// N が 0 なら無限大なのでタイマーは動かさない。
 	uint32 N = (spc.tc >> 8) << 8;
 	if (N != 0) {
-		timer_event->func = ToEventCallback(&SPCDevice::SelectionTimeout);
+		timer_event->SetCallback(&SPCDevice::SelectionTimeout);
 		timer_event->time = (N + 15) * t_CLF * 2;
 		scheduler->RestartEvent(timer_event);
 	}
