@@ -39,7 +39,7 @@ class SysClkDevice : public IODevice
 	// イベントコールバック
 	void Callback(Event *ev);
 
-	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
+	DECLARE_MONITOR_SCREEN(MonitorScreen);
 
 	// 割り込み状態をレジスタイメージにして返す
 	uint8 GetInt() const;
