@@ -179,7 +179,7 @@ VideoCtlrDevice::Poke1(uint32 addr, uint32 data)
 
 // モニタ更新の下請け。CRTC から呼ばれる。
 int
-VideoCtlrDevice::MonitorUpdate(TextScreen& screen, int y, uint32 crtc_r20)
+VideoCtlrDevice::MonitorScreen(TextScreen& screen, int y, uint32 crtc_r20)
 {
 	std::array<uint16, 3> tmp = reg;
 
@@ -648,7 +648,7 @@ VideoCtlrDevice::RenderContrast(BitmapRGBX& dst, const BitmapRGBX& src)
 
 #if defined(PERFCONT)
 		sw.Stop();
-		perf_total += sw.Elapsed();
+		perf_total += sw.Elapsed_nsec();
 		if (++perf_count % 100 == 0) {
 			printf("%" PRIu64 " usec\n", perf_total / perf_count / 1000);
 		}
