@@ -23,7 +23,7 @@ VM_Virt68k::VM_Virt68k()
 	// 機種固有パラメータ
 	// 実時間に同期したほうが便利。
 	gConfig->SetDefault("clock-sync", "real");
-	gConfig->SetDefault("hostcom-driver", "cons");
+	gConfig->SetDefault("hostcom0-driver", "console");
 	gConfig->SetDefault("mpu-type", "68030");
 	gConfig->SetDefault("mpu-clock", 25);
 	// RAM 初期値。適当。
