@@ -40,6 +40,10 @@ WXMonitorPanel::WXMonitorPanel(wxWindow *parent, Monitor *monitor_)
 	auto mainframe = dynamic_cast<WXMainFrame*>(GetParent()->GetParent());
 	SetRate(mainframe->GetMonitorRate());
 
+	// 今の所パディングは変わらない。
+	monitor->SetPadding(WXTextScreen::DefaultPadding);
+	FontChanged();
+
 	// 最初に一回描画を起こす
 	wxTimerEvent dummy(timer);
 	AddPendingEvent(dummy);
@@ -50,6 +54,15 @@ WXMonitorPanel::~WXMonitorPanel()
 {
 }
 
+// フォントサイズ変更
+void
+WXMonitorPanel::FontChanged()
+{
+	inherited::FontChanged();
+
+	monitor->SetFontSize(font_width, font_height);
+}
+
 // タイマーイベント
 void
 WXMonitorPanel::OnTimer(wxTimerEvent& event)
@@ -64,11 +77,21 @@ WXMonitorPanel::OnTimer(wxTimerEvent& event)
 void
 WXMonitorPanel::DoRefresh()
 {
+	bool updated = false;
+
 	// モニタースクリーンを更新して
-	monitor->Update(screen);
+	monitor->UpdateScreen(screen);
+	if (screen.GetBuf() != prevbuf) {
+		updated = true;
+	}
+
+	// あればビットマップ描画を足して
+	if (monitor->UpdateBitmap(bitmap)) {
+		updated = true;
+	}
 
 	// 必要なら再描画
-	if (screen.GetBuf() != prevbuf) {
+	if (updated) {
 		Refresh();
 	}
 }
