@@ -33,6 +33,8 @@ class WXStatusPanel : public WXTextPanel
 	void Fit() override;
 	bool Layout() override;
 
+	void Init();
+
  private:
 	void OnClose(wxCloseEvent&);
 	void OnShow(wxShowEvent&);
@@ -69,6 +71,7 @@ class WXStatusPanel : public WXTextPanel
 	// インジケータ表示用
 	bool ispower {};
 	bool powerled {};
+	uint clock_khz {};
 	uint perf_mode {};
 	uint perf_rate {};
 	std::array<bool, 8> scsi_loaded {};
